Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(49)

Unified Diff: pkg/observe/lib/src/compound_binding.dart

Issue 26151002: Rename runAsync to scheduleMicrotask. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Add test. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/observe/lib/src/change_notifier.dart ('k') | pkg/observe/lib/src/list_path_observer.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/observe/lib/src/compound_binding.dart
diff --git a/pkg/observe/lib/src/compound_binding.dart b/pkg/observe/lib/src/compound_binding.dart
index 94db67a84df3b1e4de661772e80292cdb498740f..b08e97d495093f9d3d7eb1fb15254e3e5638d010 100644
--- a/pkg/observe/lib/src/compound_binding.dart
+++ b/pkg/observe/lib/src/compound_binding.dart
@@ -42,7 +42,7 @@ class CompoundBinding extends ChangeNotifierBase {
* resolve.
*/
// TODO(jmesserly): I don't like having this public, is the optimization
// really needed? "runAsync" in Dart should be pretty cheap.
bool scheduled = false;
/**
@@ -101,7 +101,7 @@ class CompoundBinding extends ChangeNotifierBase {
void _scheduleResolve() {
if (scheduled) return;
scheduled = true;
- runAsync(resolve);
+ scheduleMicrotask(resolve);
}
void resolve() {
« no previous file with comments | « pkg/observe/lib/src/change_notifier.dart ('k') | pkg/observe/lib/src/list_path_observer.dart » ('j') | no next file with comments »
@@ -42,7 +42,7 @@ class CompoundBinding extends ChangeNotifierBase {
*/
// TODO(jmesserly): I don't like having this public, is the optimization
- // really needed? "runAsync" in Dart should be pretty cheap.
+ // really needed? "scheduleMicrotask" in Dart should be pretty cheap.
bool scheduled = false;
/**

Powered by Google App Engine
This is Rietveld 408576698